==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/vpnservicemulticast/multicast/rp/rpgroupmappings/rpgroupmapping/DefaultProviderManaged.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicemulticast.multicast.rp.rpgroupmappings.rpgroupmapping;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of providerManaged.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultProviderManaged extends InnerModelObject implements ProviderManaged {
    protected boolean enabled;
    protected boolean rpRedundancy;
    protected boolean optimalTrafficDelivery;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public boolean enabled() {
        return enabled;
    }

    @Override
    public boolean rpRedundancy() {
        return rpRedundancy;
    }

    @Override
    public boolean optimalTrafficDelivery() {
        return optimalTrafficDelivery;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void enabled(boolean enabled) {
        valueLeafFlags.set(LeafIdentifier.ENABLED.getLeafIndex());
        this.enabled = enabled;
    }

    @Override
    public void rpRedundancy(boolean rpRedundancy) {
        valueLeafFlags.set(LeafIdentifier.RPREDUNDANCY.getLeafIndex());
        this.rpRedundancy = rpRedundancy;
    }

    @Override
    public void optimalTrafficDelivery(boolean optimalTrafficDelivery) {
        valueLeafFlags.set(LeafIdentifier.OPTIMALTRAFFICDELIVERY.getLeafIndex());
        this.optimalTrafficDelivery = optimalTrafficDelivery;
    }

    @Override
    public int hashCode() {
        return Objects.hash(enabled, rpRedundancy, optimalTrafficDelivery, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultProviderManaged) {
            DefaultProviderManaged other = (DefaultProviderManaged) obj;
            return
                Objects.equals(enabled, other.enabled) &&
                Objects.equals(rpRedundancy, other.rpRedundancy) &&
                Objects.equals(optimalTrafficDelivery, other.optimalTrafficDelivery) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("enabled=" + enabled)
            .add("rpRedundancy=" + rpRedundancy)
            .add("optimalTrafficDelivery=" + optimalTrafficDelivery)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultProviderManaged.
     */
    public DefaultProviderManaged() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/vpnservicemulticast/multicast/rp/rpgroupmappings/rpgroupmapping/DefaultProviderManaged.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicemulticast.multicast.rp.rpgroupmappings.rpgroupmapping;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of providerManaged.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultProviderManaged extends InnerModelObject implements ProviderManaged {
    protected boolean enabled;
    protected boolean rpRedundancy;
    protected boolean optimalTrafficDelivery;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public boolean enabled() {
        return enabled;
    }

    @Override
    public boolean rpRedundancy() {
        return rpRedundancy;
    }

    @Override
    public boolean optimalTrafficDelivery() {
        return optimalTrafficDelivery;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void enabled(boolean enabled) {
        valueLeafFlags.set(LeafIdentifier.ENABLED.getLeafIndex());
        this.enabled = enabled;
    }

    @Override
    public void rpRedundancy(boolean rpRedundancy) {
        valueLeafFlags.set(LeafIdentifier.RPREDUNDANCY.getLeafIndex());
        this.rpRedundancy = rpRedundancy;
    }

    @Override
    public void optimalTrafficDelivery(boolean optimalTrafficDelivery) {
        valueLeafFlags.set(LeafIdentifier.OPTIMALTRAFFICDELIVERY.getLeafIndex());
        this.optimalTrafficDelivery = optimalTrafficDelivery;
    }

    @Override
    public int hashCode() {
        return Objects.hash(enabled, rpRedundancy, optimalTrafficDelivery, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultProviderManaged) {
            DefaultProviderManaged other = (DefaultProviderManaged) obj;
            return
                Objects.deepEquals(enabled, other.enabled) &&
                Objects.deepEquals(rpRedundancy, other.rpRedundancy) &&
                Objects.deepEquals(optimalTrafficDelivery, other.optimalTrafficDelivery) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("enabled=" + enabled)
            .add("rpRedundancy=" + rpRedundancy)
            .add("optimalTrafficDelivery=" + optimalTrafficDelivery)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultProviderManaged.
     */
    public DefaultProviderManaged() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
